pyLBM.stencil.Velocity
======================

.. currentmodule:: pyLBM.stencil

.. autoclass:: Velocity

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Velocity.get_symmetric
         Velocity.set_symmetric



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Velocity.v

